#[non_exhaustive]pub struct DevServer {
pub ip: IpAddr,
pub port: u16,
pub watch: Watch,
pub command: Option<Command>,
pub not_found_path: Option<PathBuf>,
/* private fields */
}Expand description
A simple HTTP server useful during development.
It can watch the source code for changes and restart a provided command.
Get the files at watch_path and serve them at a given IP address
(127.0.0.1:8000 by default). An optional command can be provided to restart
the build when changes are detected.
Usage
use std::process;
use xtask_wasm::{
anyhow::Result,
clap,
default_dist_dir,
};
#[derive(clap::Parser)]
enum Opt {
Start(xtask_wasm::DevServer),
Dist,
}
fn main() -> Result<()> {
let opt: Opt = clap::Parser::parse();
match opt {
Opt::Start(mut dev_server) => {
log::info!("Starting the development server...");
dev_server.arg("dist").start(default_dist_dir(false))?;
}
Opt::Dist => todo!("build project"),
}
Ok(())
}Add a start subcommand that will run cargo xtask dist, watching for
changes in the workspace and serve the files in the default dist directory
(target/debug/dist for non-release) at a given IP address.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ip: IpAddrIP address to bind. Default to 127.0.0.1.
port: u16Port number. Default to 8000.
watch: Watchcommand: Option<Command>Command executed when a change is detected.
not_found_path: Option<PathBuf>Use another file path when the URL is not found.
Implementations
Sourceimpl DevServer
impl DevServer
Sourcepub fn command(self, command: Command) -> Self
pub fn command(self, command: Command) -> Self
Set the command that is executed when a change is detected.
Sourcepub fn arg<S: AsRef<OsStr>>(self, arg: S) -> Self
pub fn arg<S: AsRef<OsStr>>(self, arg: S) -> Self
Adds an argument to pass to the command executed when changes are detected.
This will use the xtask command by default.
Sourcepub fn args<I, S>(self, args: I) -> Self
pub fn args<I, S>(self, args: I) -> Self
Adds multiple arguments to pass to the command executed when changes are detected.
This will use the xtask command by default.
Sourcepub fn not_found(self, path: impl Into<PathBuf>) -> Self
pub fn not_found(self, path: impl Into<PathBuf>) -> Self
Use another file path when the URL is not found.
Sourcepub fn request_handler<F>(self, handler: F) -> Self
pub fn request_handler<F>(self, handler: F) -> Self
Pass a custom request handler to the dev server.