#[non_exhaustive]pub struct Watch {
pub shell_commands: Vec<String>,
pub cargo_commands: Vec<String>,
pub watch_paths: Vec<PathBuf>,
pub exclude_paths: Vec<PathBuf>,
pub workspace_exclude_paths: Vec<PathBuf>,
pub debounce: Duration,
}Expand description
Watches over your project’s source code, relaunching a given command when changes are detected.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.shell_commands: Vec<String>Shell command(s) to execute on changes.
cargo_commands: Vec<String>Cargo command(s) to execute on changes.
The default is [ check ]
watch_paths: Vec<PathBuf>Watch specific file(s) or folder(s).
The default is the workspace root.
exclude_paths: Vec<PathBuf>Paths that will be excluded.
workspace_exclude_paths: Vec<PathBuf>Paths, relative to the workspace root, that will be excluded.
debounce: DurationThrottle events to prevent the command to be re-executed too early right after an execution already occurred.
The default is 2 seconds.
Implementations
Sourceimpl Watch
impl Watch
Sourcepub fn watch_path(self, path: impl AsRef<Path>) -> Watch
pub fn watch_path(self, path: impl AsRef<Path>) -> Watch
Add a path to watch for changes.
Sourcepub fn watch_paths(
self,
paths: impl IntoIterator<Item = impl AsRef<Path>>,
) -> Watch
pub fn watch_paths( self, paths: impl IntoIterator<Item = impl AsRef<Path>>, ) -> Watch
Add multiple paths to watch for changes.
Sourcepub fn exclude_path(self, path: impl AsRef<Path>) -> Watch
pub fn exclude_path(self, path: impl AsRef<Path>) -> Watch
Add a path that will be ignored if changes are detected.
Sourcepub fn exclude_paths(
self,
paths: impl IntoIterator<Item = impl AsRef<Path>>,
) -> Watch
pub fn exclude_paths( self, paths: impl IntoIterator<Item = impl AsRef<Path>>, ) -> Watch
Add multiple paths that will be ignored if changes are detected.
Sourcepub fn exclude_workspace_path(self, path: impl AsRef<Path>) -> Watch
pub fn exclude_workspace_path(self, path: impl AsRef<Path>) -> Watch
Add a path, relative to the workspace, that will be ignored if changes are detected.
Sourcepub fn exclude_workspace_paths(
self,
paths: impl IntoIterator<Item = impl AsRef<Path>>,
) -> Watch
pub fn exclude_workspace_paths( self, paths: impl IntoIterator<Item = impl AsRef<Path>>, ) -> Watch
Add multiple paths, relative to the workspace, that will be ignored if changes are detected.