DevServer

Struct DevServer 

#[non_exhaustive]
pub struct DevServer { pub ip: IpAddr, pub port: u16, pub watch: Watch, pub dist_dir: Option<PathBuf>, pub pre_hooks: Vec<Box<dyn Hook>>, pub command: Option<Command>, pub post_hooks: Vec<Box<dyn Hook>>, pub not_found_path: Option<PathBuf>, /* private fields */ }
Available on non-WebAssembly only.
A simple HTTP server useful during development.

It can watch the source code for changes and restart a provided command.

Serve the file from the provided dist_dir at a given IP address (127.0.0.1:8000 by default). An optional command can be provided to restart the build when changes are detected using command, xtask or cargo.

Usage

use std::process;
use xtask_wasm::{
    anyhow::Result,
    clap,
};

#[derive(clap::Parser)]
enum Opt {
    Start(xtask_wasm::DevServer),
    Dist,
}

fn main() -> Result<()> {
    let opt: Opt = clap::Parser::parse();

    match opt {
        Opt::Dist => todo!("build project"),
        Opt::Start(dev_server) => {
            log::info!("Starting the development server...");
            dev_server
                .xtask("dist")
                .start()?;
        }
    }

    Ok(())
}

This adds a start subcommand that will run cargo xtask dist, watching for changes in the workspace and serve the files in the default dist directory (target/debug/dist) at the default IP address.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
ip: IpAddr

IP address to bind. Default to 127.0.0.1.

port: u16

Port number. Default to 8000.

watch: Watch

Watch configuration for detecting file-system changes.

Controls which paths are watched, debounce timing, and other watch behaviour. Watching is only active when at least one of pre_hooks, command, or post_hooks is set; if none are provided the watch thread is not started.

dist_dir: Option<PathBuf>

Directory of all generated artifacts.

pre_hooks: Vec<Box<dyn Hook>>

Commands executed before the main command when a change is detected.

command: Option<Command>

Main command executed when a change is detected.

post_hooks: Vec<Box<dyn Hook>>

Commands executed after the main command when a change is detected.

not_found_path: Option<PathBuf>

Use another file path when the URL is not found.

Implementations

Source

impl DevServer

pub fn address(self, ip: IpAddr, port: u16) -> Self

Set the dev-server binding address.

pub fn dist_dir(self, path: impl Into<PathBuf>) -> Self

Set the directory for the generated artifacts.

The default is target/debug/dist.

pub fn pre(self, command: impl Hook + 'static) -> Self

Add a command to execute before the main command when a change is detected.

pub fn pres( self, commands: impl IntoIterator<Item = impl Hook + 'static>, ) -> Self

Add multiple commands to execute before the main command when a change is detected.

pub fn post(self, command: impl Hook + 'static) -> Self

Add a command to execute after the main command when a change is detected.

pub fn posts( self, commands: impl IntoIterator<Item = impl Hook + 'static>, ) -> Self

Add multiple commands to execute after the main command when a change is detected.

pub fn command(self, command: Command) -> Self

Main command executed when a change is detected.

See xtask if you want to use an xtask command.

pub fn xtask(self, name: impl AsRef<str>) -> Self

Name of the main xtask command that is executed when a change is detected.

See command to use an arbitrary command.

pub fn cargo(self, subcommand: impl AsRef<str>) -> Self

Cargo subcommand executed as the main command when a change is detected.

See xtask for xtask commands or command for arbitrary commands.

pub fn arg<S: AsRef<OsStr>>(self, arg: S) -> Self

Adds an argument to the main command executed when changes are detected.

Panics

Panics if called before command, xtask or cargo.

pub fn args<I, S>(self, args: I) -> Self
where I: IntoIterator<Item = S>, S: AsRef<OsStr>,

Adds multiple arguments to the main command executed when changes are detected.

Panics

Panics if called before command, xtask or cargo.

pub fn env<K, V>(self, key: K, val: V) -> Self
where K: AsRef<OsStr>, V: AsRef<OsStr>,

Inserts or updates an environment variable for the main command executed when changes are detected.

Panics

Panics if called before command, xtask or cargo.

pub fn envs<I, K, V>(self, vars: I) -> Self
where I: IntoIterator<Item = (K, V)>, K: AsRef<OsStr>, V: AsRef<OsStr>,

Inserts or updates multiple environment variables for the main command executed when changes are detected.

Panics

Panics if called before command, xtask or cargo.

pub fn not_found_path(self, path: impl Into<PathBuf>) -> Self

Use another file path when the URL is not found.

pub fn request_handler<F>(self, handler: F) -> Self
where F: Fn(Request<'_>) -> Result<()> + Send + Sync + 'static,

Pass a custom request handler to the dev server.

pub fn start(self) -> Result<()>

Start the server, serving the files at dist_dir.

If dist_dir has not been provided, Dist::default_debug_dir will be used.